@@ -20,7 +20,6 @@ directly from the `testing` package::
     from falcon import testing
 
     wsgi_environ = testing.create_environ()
-
 """
 
 import asyncio
@@ -303,8 +302,8 @@ class ASGIResponseEventCollector:
         ]
     )
 
-    _HEADER_NAME_RE = re.compile(br'^[a-zA-Z][a-zA-Z0-9\-_]*$')
-    _BAD_HEADER_VALUE_RE = re.compile(br'[\000-\037]')
+    _HEADER_NAME_RE = re.compile(rb'^[a-zA-Z][a-zA-Z0-9\-_]*$')
+    _BAD_HEADER_VALUE_RE = re.compile(rb'[\000-\037]')
 
     def __init__(self):
         self.events = []
@@ -802,7 +801,7 @@ def get_encoding_from_headers(headers):
     content_type, params = cgi.parse_header(content_type)
 
     if 'charset' in params:
-        return params['charset'].strip("'\"")
+        return params['charset'].strip('\'"')
 
     # NOTE(kgriffs): Added checks for text/event-stream and application/json
     if content_type in ('text/event-stream', 'application/json'):
@@ -1151,7 +1150,8 @@ def create_environ(
     body = io.BytesIO(body.encode() if isinstance(body, str) else body)
 
     # NOTE(kgriffs): wsgiref, gunicorn, and uWSGI all unescape
-    # the paths before setting PATH_INFO
+    # the paths before setting PATH_INFO but preserve raw original
+    raw_path = path
     path = uri.decode(path, unquote_plus=False)
 
     # NOTE(kgriffs): The decoded path may contain UTF-8 characters.
@@ -1194,7 +1194,7 @@ def create_environ(
         'PATH_INFO': path,
         'QUERY_STRING': query_string,
         'REMOTE_PORT': '65133',
-        'RAW_URI': '/',
+        'RAW_URI': raw_path,
         'SERVER_NAME': host,
         'SERVER_PORT': port,
         'wsgi.version': (1, 0),
